@@ -1,5 +1,4 @@
 /**
- * $Id: stataread.c,v 1.14 2004/04/28 15:33:40 tlumley Exp $
   Read  Stata version 8.0, 7.0, 7/SE, 6.0 and 5.0 .dta files, write version 7.0, 6.0.
   
   (c) 1999, 2000, 2001, 2002 Thomas Lumley. 
@@ -468,9 +467,6 @@ SEXP R_LoadStataData(FILE *fp)
 
     /** tidy up **/
 
-    PROTECT(tmp = mkString("data.frame"));
-    setAttrib(df, R_ClassSymbol, tmp);
-    UNPROTECT(1);
     PROTECT(row_names = allocVector(STRSXP, nobs));
     for (i=0; i<nobs; i++) {
         sprintf(datalabel, "%d", i+1);
@@ -565,6 +561,7 @@ static void  OutDoubleBinary(double d, FILE * fp, int naok)
 
 static void OutStringBinary(char *buffer, FILE * fp, int nchar)
 {
+    if (nchar==0) return;
     if (fwrite(buffer, nchar, 1, fp) != 1)
 	error(_("a binary write error occurred"));
 }
